@@ -13,8 +13,13 @@ sub handle_day_change {
 	my (%opt)       = @_;
 	my $datestr     = $opt{date};
 	my $timestr     = $opt{time};
+	my $tz_offset   = $opt{offset};
 	my $offset_days = 0;
 
+	if ( not defined $timestr ) {
+		return;
+	}
+
 	# timestr may include a day offset, resulting in DDHHMMSS
 	if ( length($timestr) == 8 ) {
 		$offset_days = substr( $timestr, 0, 2, q{} );
@@ -26,6 +31,11 @@ sub handle_day_change {
 		$ts->add( days => $offset_days );
 	}
 
+	if ( defined $tz_offset and $tz_offset != $ts->offset / 60 ) {
+		my $ts_offset = $tz_offset - $ts->offset / 60;
+		$ts->subtract( minutes => $ts_offset );
+	}
+
 	return $ts;
 }
 
@@ -43,7 +53,7 @@ None.
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 METHODS
 
